import * as React from 'react';
import { Button } from '@blueprintjs/core';
import { ArrayFieldTemplateProps } from 'react-jsonschema-form';

import { ArrayItem } from './ArrayItem';

export const ArrayFieldTemplate: React.SFC<ArrayFieldTemplateProps> = ({
  className,
  idSchema,
  uiSchema,
  schema,

  required,
  title,
  TitleField,

  DescriptionField,

  items,

  canAdd,
  disabled,
  readonly,
  onAddClick
}) => (
    <div
      className={`rjsf-bp3-array ${className}`}
      id={idSchema.$id}
    >
      <TitleField
        id={`${idSchema.$id}.__title`}
        title={title}
        required={required}
      />

      {(uiSchema['ui:description'] || schema.description) && (
        <DescriptionField
          id={`${idSchema.$id}.__description`}
          description={uiSchema['ui:description'] || schema.description}
        />
      )}

      <div className='rjsf-bp3-array-items'>
        {items && items.map(ArrayItem)}
      </div>

      {canAdd && (
        <div className='rjsf-bp3-array-add'>
          <Button
            icon='plus'
            intent='primary'
            tabIndex={-1}
            disabled={disabled || readonly}
            onClick={onAddClick}
          />
        </div>
      )}
    </div>
  )
