import * as React from 'react';
import { Button, ButtonGroup } from '@blueprintjs/core';
import { ArrayFieldTemplateProps } from 'react-jsonschema-form';

type ArrayItem<T extends any[]> = T extends Array<infer U> ? U : never;

type Props = ArrayItem<ArrayFieldTemplateProps['items']>;

export const ArrayItem: React.SFC<Props> = ({
  children,
  disabled,
  hasMoveDown,
  hasMoveUp,
  hasRemove,
  hasToolbar,
  index,
  onDropIndexClick,
  onReorderClick,
  readonly
}) =>
  <div key={index} className='rjsf-bp3-array-item'>
    <div
      className='rjsf-bp3-array-item-children'
    >
      {children}
    </div>

    {hasToolbar && (
      <div
        className='rjsf-bp3-array-item-toolbar'
      >
        <ButtonGroup>
          {(hasMoveUp || hasMoveDown) && (
            <>
              <Button
                icon='chevron-up'
                className='rjsf-bp3-array-item-move-up'
                tabIndex={-1}
                disabled={disabled || readonly || !hasMoveUp}
                onClick={onReorderClick(index, index - 1)}
              />
              <Button
                icon='chevron-down'
                className='rjsf-bp3-array-item-move-down'
                tabIndex={-1}
                disabled={disabled || readonly || !hasMoveDown}
                onClick={onReorderClick(index, index + 1)}
              />
            </>
          )}
          {(hasRemove) && (
            <Button
              icon='cross'
              className='rjsf-bp3-array-item-remove'
              intent='danger'
              tabIndex={-1}
              disabled={disabled || readonly}
              onClick={onDropIndexClick(index)}
            />
          )}
        </ButtonGroup>
      </div>
    )}
  </div>
