import * as React from 'react';
import { Button, InputGroup, FormGroup } from '@blueprintjs/core';
import { FieldTemplateProps } from 'react-jsonschema-form';
import { ADDITIONAL_PROPERTY_FLAG } from 'react-jsonschema-form/lib/utils';

export class FieldTemplate extends React.Component<FieldTemplateProps> {
  render() {
    const { children, hidden } = this.props;

    if (hidden) {
      return (
        <div className='hidden'>{children}</div>
      );
    }

    const {
      classNames,
      displayLabel,
      id,
      label,
      required,
      errors,
      rawErrors = [],
      help,
      rawHelp,
      schema,
    } = this.props;

    const value = (
      <FormGroup
        className={classNames}
        labelInfo={required ? '(required)' : undefined}
        labelFor={id}
        label={displayLabel ? label : undefined}
        intent={rawErrors.length ? 'danger' : 'none'}
        helperText={rawErrors.length || rawHelp ? (
          <>
            {errors}
            {help}
          </>
        ) : undefined}
      >
        {children}
      </FormGroup>
    )

    const additional = schema.hasOwnProperty(ADDITIONAL_PROPERTY_FLAG);

    if (!additional) {
      return value;
    }

    const {
      disabled,
      readonly,
      onDropPropertyClick
    } = this.props as any;

    return (
      <div className='rjsf-bp3-additional-property'>
        <div className='rjsf-bp3-additional-property-key'>
          <FormGroup
            className={classNames}
            labelFor={`${id}-key`}
            label={`${label} Key`}
          >
            <InputGroup
              defaultValue={label}
              id={`${id}-key`}
              onBlur={this._onKeyChange}
            />
          </FormGroup>
        </div>
        <div className='rjsf-bp3-additional-property-value'>
          {value}
        </div>
        <div className='rjsf-bp3-additional-property-remove'>
          <Button
            icon='cross'
            intent='danger'
            tabIndex={-1}
            disabled={disabled || readonly}
            onClick={onDropPropertyClick(label)}
          />
        </div>
      </div>
    )
  }

  protected _onKeyChange: React.ChangeEventHandler<HTMLInputElement> = event => {
    (this.props as any).onKeyChange(event.target.value);
  }
}
