import * as React from 'react';
import { Button } from '@blueprintjs/core';
import BaseForm, { FormProps as BaseFormProps } from 'react-jsonschema-form';

import { ArrayFieldTemplate } from './ArrayFieldTemplate';
import { ErrorList } from './ErrorList';
import { FieldTemplate } from './FieldTemplate';
import { ObjectFieldTemplate } from './ObjectFieldTemplate';
import * as customWidgets from './widgets';
import * as customFields from './fields';

type Props<T> = BaseFormProps<T> & Partial<{
  forwardedRef: React.Ref<BaseForm<T>>
}>

export class _Form<T = {}> extends React.Component<Props<T>> {
  static defaultProps = {
    ArrayFieldTemplate,
    ErrorList,
    FieldTemplate,
    ObjectFieldTemplate,
    widgets: {},
    fields: {},
    noHtml5Validate: true
  }

  render() {
    const { children, fields, widgets, forwardedRef, ...props } = this.props;

    return (
      <BaseForm
        {...props}
        widgets={{
          ...customWidgets as any,
          ...widgets
        }}
        fields={{
          ...customFields as any,
          ...fields
        }}
        ref={forwardedRef}
      >
        {children || (
          <Button
            type='submit'
            text='Submit'
            intent='primary'
            disabled={props.disabled}
          />
        )}
      </BaseForm>
    )
  }
}

export const Form = React.forwardRef<BaseForm<any>, BaseFormProps<any>>((props, ref) => (
  <_Form {...props} forwardedRef={ref} />
));
