import * as React from 'react';
import { Button } from '@blueprintjs/core';
import { ObjectFieldTemplateProps } from 'react-jsonschema-form';
import { getUiOptions } from 'react-jsonschema-form/lib/utils';

// Copypaste from react-jsonschema-form/src/components/fields/ObjectField.js
const canExpand = ({ formData, schema, uiSchema }: ObjectFieldTemplateProps) => {
  if (!schema.additionalProperties) {
    return false;
  }
  const { expandable } = getUiOptions(uiSchema);
  if (expandable === false) {
    return expandable;
  }
  // if ui:options.expandable was not explicitly set to false, we can add
  // another property if we have not exceeded maxProperties yet
  if (schema.maxProperties !== undefined) {
    return Object.keys(formData).length < schema.maxProperties;
  }
  return true;
};

export const ObjectFieldTemplate: React.SFC<ObjectFieldTemplateProps> = props => {
  const {
    TitleField,
    DescriptionField,
    onAddClick,
    disabled,
    readonly
  } = props as any;

  return (
    <fieldset id={props.idSchema.$id}>
      {(props.uiSchema["ui:title"] || props.title) && (
        <TitleField
          id={`${props.idSchema.$id}__title`}
          title={props.title || props.uiSchema["ui:title"]}
          required={props.required}
          formContext={props.formContext}
        />
      )}
      {props.description && (
        <DescriptionField
          id={`${props.idSchema.$id}__description`}
          description={props.description}
          formContext={props.formContext}
        />
      )}
      {props.properties.map(prop => prop.content)}
      {canExpand(props) && (
        <div className='rjsf-bp3-object-property-expand'>
          <Button
            icon='plus'
            intent='primary'
            onClick={onAddClick(props.schema)}
            disabled={disabled || readonly}
          />
        </div>
      )}
    </fieldset>
  );
}
