import * as React from 'react';
import { FormGroup, HTMLSelect } from '@blueprintjs/core';
import BaseMultiSchemaField from 'react-jsonschema-form/lib/components/fields/MultiSchemaField';

export class MultiSchemaField extends BaseMultiSchemaField {
  render() {
    const {
      baseType,
      disabled,
      errorSchema,
      formData,
      idPrefix,
      idSchema,
      onBlur,
      onChange,
      onFocus,
      options,
      registry,
      safeRenderCompletion,
      uiSchema,
    } = this.props;

    const _SchemaField = registry.fields.SchemaField as any;
    const { selectedOption } = this.state;

    const option = options[selectedOption] || null;
    let optionSchema;

    if (option) {
      // If the subschema doesn't declare a type, infer the type from the
      // parent schema
      optionSchema = option.type
        ? option
        : Object.assign({}, option, { type: baseType });
    }

    return (
      <div className="panel panel-default panel-body">
        <FormGroup>
          <HTMLSelect
            fill
            onChange={this.onOptionChange}
            value={selectedOption}
            id={`${idSchema.$id}_anyof_select`}>
            {options.map((option, index) => {
              return (
                <option key={index} value={index}>
                  {option.title || `Option ${index + 1}`}
                </option>
              );
            })}
          </HTMLSelect>
        </FormGroup>

        {option !== null && (
          <_SchemaField
            schema={optionSchema}
            uiSchema={uiSchema}
            errorSchema={errorSchema}
            idSchema={idSchema}
            idPrefix={idPrefix}
            formData={formData}
            onChange={onChange}
            onBlur={onBlur}
            onFocus={onFocus}
            registry={registry}
            safeRenderCompletion={safeRenderCompletion}
            disabled={disabled}
          />
        )}
      </div>
    );
  }
}
