import { JSONSchema6 } from 'json-schema';
import { asNumber, guessType } from 'react-jsonschema-form/lib/utils';

// Copypaste from react-jsonschema-form/src/components/widgets/SelectWidget.js
const nums = new Set(["number", "integer"]);

export const processValue = (schema: JSONSchema6, value: any | any[]) => {
  // "enum" is a reserved word, so only "type" and "items" can be destructured
  const { type, items } = schema;
  if (value === "") {
    return undefined;
  } else if (type === "array" && items && nums.has((items as any).type)) {
    return value.map(asNumber);
  } else if (type === "boolean") {
    return value === "true";
  } else if (type === "number") {
    return asNumber(value);
  }

  // If type is undefined, but an enum is present, try and infer the type from
  // the enum values
  if (schema.enum) {
    if (schema.enum.every(x => guessType(x) === "number")) {
      return asNumber(value);
    } else if (schema.enum.every(x => guessType(x) === "boolean")) {
      return value === "true";
    }
  }

  return value;
}

export const getValue = (event: React.ChangeEvent<HTMLSelectElement>, multiple: boolean) => {
  if (multiple) {
    return [].slice
      .call(event.target.options)
      .filter((o: any) => o.selected)
      .map((o: any) => o.value);
  } else {
    return event.target.value;
  }
}
