import * as React from 'react';
import { Checkbox } from '@blueprintjs/core';
import { JSONSchema6 } from 'json-schema';
import { WidgetProps } from 'react-jsonschema-form';

type Props = WidgetProps & {
  label: string;
};

// Copypaste from react-jsonschema-form/src/components/widgets/CheckboxWidget.js
function schemaRequiresTrueValue(schema: JSONSchema6): boolean {
  // Check if const is a truthy value
  if (schema.const) {
    return true;
  }

  // Check if an enum has a single value of true
  if (schema.enum && schema.enum.length === 1 && schema.enum[0] === true) {
    return true;
  }

  // If anyOf has a single value, evaluate the subschema
  if (schema.anyOf && schema.anyOf.length === 1) {
    return schemaRequiresTrueValue((schema.anyOf as JSONSchema6[])[0]);
  }

  // If oneOf has a single value, evaluate the subschema
  if (schema.oneOf && schema.oneOf.length === 1) {
    return schemaRequiresTrueValue((schema.oneOf as JSONSchema6[])[0]);
  }

  // Evaluate each subschema in allOf, to see if one of them requires a true
  // value
  if (schema.allOf) {
    return (schema.allOf as JSONSchema6[]).some(schemaRequiresTrueValue);
  }

  return true;
}

export class CheckboxWidget extends React.Component<Props> {
  render() {
    const { value, disabled, readonly, autofocus, schema, id, label } = this.props;

    return (
      <Checkbox
        checked={typeof value === 'undefined' ? false : value}
        disabled={disabled || readonly}
        autoFocus={autofocus}
        required={schemaRequiresTrueValue(schema)}
        onChange={this._onChange}
        onBlur={this._onBlur}
        onFocus={this._onFocus}
        {...{ id, label }}
      />
    );
  }

  protected _onChange: React.ChangeEventHandler<HTMLInputElement> = event =>
    this.props.onChange(event.target.checked)

  protected _onBlur: React.ChangeEventHandler<HTMLInputElement> = event =>
    this.props.onBlur && this.props.onBlur(this.props.id, event.target.checked as any)

  protected _onFocus: React.ChangeEventHandler<HTMLInputElement> = event =>
    this.props.onFocus && this.props.onFocus(this.props.id, event.target.checked as any)
}
