import * as React from 'react';
import { Checkbox, ICheckboxProps } from '@blueprintjs/core';
import { WidgetProps } from 'react-jsonschema-form';

type SupportedOptions = 'inline';

type Option = {
  value: string;
  label: string;
}

type Props = WidgetProps & {
  options: Pick<ICheckboxProps, SupportedOptions> & {
    enumOptions: Option[];
    enumDisabled?: string[]
  }
};

const append = (needle: string, haystack: string[], all: string[]) => {
  const originalIndex = all.indexOf(needle);
  const updated = haystack.slice(0, originalIndex).concat(needle, haystack.slice(originalIndex));
  return updated.sort((a, b) => all.indexOf(a) - all.indexOf(b));
}

const without = (needle: string, haystack: string[]) =>
  haystack.filter(value => value !== needle);

export class CheckboxesWidget extends React.Component<Props> {
  render() {
    const { options: { enumOptions, enumDisabled, inline }, id, value, disabled, autofocus } = this.props;

    return enumOptions.map((option, index) => {
      const checked = value.indexOf(option.value) > -1;
      const itemDisabled = enumDisabled && enumDisabled.indexOf(option.value) > -1;

      return (
        <Checkbox
          id={`${id}_${index}`}
          key={index}
          disabled={disabled || itemDisabled}
          autoFocus={autofocus && index === 0}
          onChange={this._onChange(option.value)}
          label={option.label}
          {...{ checked, inline }}
        />
      );
    });
  }

  protected _onChange = (optionValue: string) =>
    (event: React.ChangeEvent<HTMLInputElement>) => {
      const { onChange, value } = this.props;

      if (!event.target.checked) {
        return onChange(without(optionValue, value));
      }

      const { options: { enumOptions } } = this.props;
      const options = enumOptions.map(option => option.value);

      return onChange(append(optionValue, value, options));
    }
}
