import * as React from 'react';

import { DateInput, IDateInputProps } from '@blueprintjs/datetime';
import { WidgetProps } from 'react-jsonschema-form';

type SupportedOptions = 'formatDate' | 'parseDate';

export type Props = WidgetProps & {
  options: Partial<Pick<IDateInputProps, SupportedOptions> & {
    fill: boolean;
  }>
};

export class DateTimeWidget extends React.Component<Props> {
  static defaultProps = {
    options: {
      className: 'rjsf-bp3-date-input',
      fill: true,
      timePickerProps: {},
      showActionsBar: true,
      formatDate: (date: Date) => date.toLocaleString(),
      parseDate: (str: string) => new Date(str)
    }
  }

  render() {
    const { value, options } = this.props;

    return (
      <DateInput
        value={value ? new Date(value) : undefined}
        onChange={this._onChange}
        popoverProps={{ className: options.fill ? 'bp3-fill' : undefined }}
        inputProps={{ className: options.fill ? 'bp3-fill' : undefined }}
        {...options}
      />
    );
  }

  protected _onChange = (date?: Date) =>
    this.props.onChange(date ? date.toJSON() : undefined);
}
