import * as React from 'react';
import BaseFileWidget from 'react-jsonschema-form/lib/components/widgets/FileWidget';
import { FileInput, IFileInputProps, UL } from '@blueprintjs/core';
import { WidgetProps } from 'react-jsonschema-form';

type SupportedOptions = 'fill';

type Props = WidgetProps & {
  multiple: boolean;
  options: Pick<IFileInputProps, SupportedOptions>
}

export class FileWidget extends BaseFileWidget {
  render() {
    const {
      id,
      multiple,
      readonly,
      disabled,
      options: {
        fill = true
      }
    } = this.props as Props;

    return (
      <>
        <FileInput
          disabled={disabled || readonly}
          inputProps={{
            multiple
          }}
          text={this._renderText()}
          onInputChange={this.onChange}
          {...{ id, fill }}
        />
        {this._renderFiles()}
      </>
    );
  }

  protected _renderText = () => {
    const { filesInfo } = this.state;

    if (filesInfo.length === 0) {
      return;
    }

    if (filesInfo.length === 1) {
      return filesInfo[0].name;
    }

    return `${filesInfo.length} Files`;
  }

  protected _renderFiles = () => {
    const { filesInfo } = this.state;

    if (filesInfo.length < 2) {
      return;
    }

    return (
      <UL>
        {filesInfo.map(({ name, type, size }) => (
          <li key={name}>
            <strong>{name}</strong> ({type}, {size} bytes)
          </li>
        ))}
      </UL>
    );
  }
}
