import * as React from 'react';
import { Radio, RadioGroup, IRadioGroupProps } from '@blueprintjs/core';
import { WidgetProps } from 'react-jsonschema-form';

import { processValue } from '../utils';

type SupportedOptions = 'inline';

type Props = WidgetProps & {
  options: Pick<IRadioGroupProps, SupportedOptions> & {
    enumOptions: Array<{
      value: string;
      label: string;
    }>;
    enumDisabled?: string[]
  }
}

export class RadioWidget extends React.Component<Props> {
  render() {
    const {
      autofocus,
      disabled,
      id,
      options,
      value,
    } = this.props;

    return (
      <RadioGroup
        name={id}
        onChange={this._onChange}
        selectedValue={value}
        disabled={disabled}
        inline={options.inline}
      >
        {...options.enumOptions.map(({ value, label }, index) => (
          <Radio
            key={index}
            label={label}
            value={value}
            autoFocus={autofocus && index === 0}
          />
        ))}
      </RadioGroup>
    );
  }

  protected _onChange: React.FormEventHandler<HTMLInputElement> = event => {
    const { schema, onChange } = this.props;
    const value = processValue(schema, (event as React.ChangeEvent<HTMLInputElement>).target.value);
    onChange(value);
  }
}
