import * as React from 'react';
import { Slider, ISliderProps } from '@blueprintjs/core';
import { WidgetProps } from 'react-jsonschema-form';

type SupportedOptions = 'labelStepSize' | 'vertical';

type Props = WidgetProps & {
  options: Partial<Pick<ISliderProps, SupportedOptions>>
}

export const RangeWidget: React.SFC<Props> =
  ({ schema, value, options, ...inputProps }) =>
    <Slider
      value={value === null ? '' : value}
      min={schema.minimum ? schema.minimum : undefined}
      max={schema.maximum ? schema.maximum : undefined}
      stepSize={schema.multipleOf ? schema.multipleOf : undefined}
      labelStepSize={labelStepSize({ schema, options })}
      vertical={options.vertical}
      {...inputProps}
    />

const labelStepSize = ({ options, schema }: Pick<Props, 'options' | 'schema'>) => {
  if (options.labelStepSize) {
    return options.labelStepSize;
  }

  if (schema.multipleOf) {
    return schema.multipleOf;
  }

  if (schema.maximum && schema.minimum) {
    return schema.maximum - schema.minimum;
  }

  if (schema.maximum) {
    return schema.maximum;
  }
}
