import * as React from 'react';
import { HTMLSelect, IHTMLSelectProps } from '@blueprintjs/core';
import { WidgetProps } from 'react-jsonschema-form';

import { getValue, processValue } from '../utils';

type SupportedOptions = 'fill';

type Props = WidgetProps & {
  multiple: any;
  options: Pick<IHTMLSelectProps, SupportedOptions> & {
    enumOptions: Array<{
      value: string;
      label: string;
    }>;
    enumDisabled?: string[]
  }
}

export class SelectWidget extends React.Component<Props> {
  render() {
    const {
      autofocus,
      disabled,
      multiple,
      id,
      options,
      placeholder,
      readonly,
      required,
      schema,
      value,
    } = this.props;

    const { enumOptions, enumDisabled, fill = true, } = options;
    const emptyValue = multiple ? [] : '';

    return (
      <HTMLSelect
        autoFocus={autofocus}
        value={typeof value === 'undefined' ? emptyValue : value}
        disabled={disabled || readonly}
        onBlur={this._onBlur}
        onFocus={this._onFocus}
        onChange={this._onChange}
        {...{ id, multiple, required, fill }}
      >
        {!multiple && !schema.default && <option value="">{placeholder}</option>}
        {enumOptions.map(({ value, label }, index) => {
          const disabled = enumDisabled ? enumDisabled.indexOf(value) > -1 : false;
          return (
            <option key={index} value={value} disabled={disabled}>
              {label}
            </option>
          )
        })}
      </HTMLSelect>
    );
  }

  protected _onBlur: React.EventHandler<any> = event => {
    const { id, multiple, onBlur, schema } = this.props;

    if (!onBlur) {
      return;
    }

    const value = getValue(event, multiple);
    onBlur(id, processValue(schema, value));
  }

  protected _onFocus: React.EventHandler<any> = event => {
    const { id, multiple, onFocus, schema } = this.props;

    if (!onFocus) {
      return;
    }

    const value = getValue(event, multiple);
    onFocus(id, processValue(schema, value));
  }

  protected _onChange: React.EventHandler<any> = event => {
    const { multiple, onChange, schema } = this.props;

    if (!onChange) {
      return;
    }

    const value = getValue(event, multiple);
    onChange(processValue(schema, value));
  }
}
