import * as React from 'react';
import { TextArea, ITextAreaProps } from '@blueprintjs/core';
import { WidgetProps } from 'react-jsonschema-form';

type SupportedOptions = 'fill' | 'rows';

type Props = WidgetProps & Pick<ITextAreaProps, SupportedOptions>;

export class TextareaWidget extends React.Component<Props> {
  protected _onChange: React.ChangeEventHandler<HTMLTextAreaElement> = event =>
    this.props.onChange(event.target.value === '' ? (this.props.options as any).emptyValue : event.target.value)

  protected _onBlur: React.EventHandler<any> = event =>
    this.props.onBlur && this.props.onBlur(this.props.id, event.target.value)

  protected _onFocus: React.EventHandler<any> = event =>
    this.props.onFocus && this.props.onFocus(this.props.id, event.target.value)

  render() {
    const {
      id,
      value,
      disabled,
      placeholder,
      required,
      readonly,
      autofocus,
      options
    }: WidgetProps & { options: any } = this.props;

    const {
      fill = true,
      rows
    } = options;

    return (
      <TextArea
        value={value == null ? '' : value}
        onChange={this._onChange}
        onBlur={this._onBlur}
        onFocus={this._onFocus}
        readOnly={readonly}
        autoFocus={autofocus}
        {...{ id, disabled, placeholder, required, fill, rows }}
      />
    );
  }
}
